==> openshift-model-operator-6.9.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/StaticIPAMRoutesFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class StaticIPAMRoutesFluent<A extends StaticIPAMRoutesFluent<A>> extends BaseFluent<A>{
  public StaticIPAMRoutesFluent() {
  }
  
  public StaticIPAMRoutesFluent(StaticIPAMRoutes instance) {
    this.copyInstance(instance);
  }
  private String destination;
  private String gateway;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(StaticIPAMRoutes instance) {
    instance = (instance != null ? instance : new StaticIPAMRoutes());
  
    if (instance != null) {
        this.withDestination(instance.getDestination());
        this.withGateway(instance.getGateway());
        this.withDestination(instance.getDestination());
        this.withGateway(instance.getGateway());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getDestination() {
    return this.destination;
  }
  
  public A withDestination(String destination) {
    this.destination=destination; return (A) this;
  }
  
  public boolean hasDestination() {
    return this.destination != null;
  }
  
  public String getGateway() {
    return this.gateway;
  }
  
  public A withGateway(String gateway) {
    this.gateway=gateway; return (A) this;
  }
  
  public boolean hasGateway() {
    return this.gateway != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StaticIPAMRoutesFluent that = (StaticIPAMRoutesFluent) o;
    if (!java.util.Objects.equals(destination, that.destination)) return false;
  
    if (!java.util.Objects.equals(gateway, that.gateway)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(destination,  gateway,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (destination != null) { sb.append("destination:"); sb.append(destination + ","); }
    if (gateway != null) { sb.append("gateway:"); sb.append(gateway + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-operator-6.9.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/StaticIPAMRoutesFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class StaticIPAMRoutesFluent<A extends StaticIPAMRoutesFluent<A>> extends BaseFluent<A>{
  public StaticIPAMRoutesFluent() {
  }
  
  public StaticIPAMRoutesFluent(StaticIPAMRoutes instance) {
    this.copyInstance(instance);
  }
  private String destination;
  private String gateway;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(StaticIPAMRoutes instance) {
    instance = (instance != null ? instance : new StaticIPAMRoutes());
    if (instance != null) {
          this.withDestination(instance.getDestination());
          this.withGateway(instance.getGateway());
          this.withDestination(instance.getDestination());
          this.withGateway(instance.getGateway());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getDestination() {
    return this.destination;
  }
  
  public A withDestination(String destination) {
    this.destination = destination;
    return (A) this;
  }
  
  public boolean hasDestination() {
    return this.destination != null;
  }
  
  public String getGateway() {
    return this.gateway;
  }
  
  public A withGateway(String gateway) {
    this.gateway = gateway;
    return (A) this;
  }
  
  public boolean hasGateway() {
    return this.gateway != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StaticIPAMRoutesFluent that = (StaticIPAMRoutesFluent) o;
    if (!java.util.Objects.equals(destination, that.destination)) return false;
    if (!java.util.Objects.equals(gateway, that.gateway)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(destination,  gateway,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (destination != null) { sb.append("destination:"); sb.append(destination + ","); }
    if (gateway != null) { sb.append("gateway:"); sb.append(gateway + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
